@@ -469,16 +469,12 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
 	
 	return model    
 
-if __name__ == "__main__":
-	pass
-else:
+if __name__ != "__main__":
 	#print("Please refer to help(create_model) to know about how to use.\n")
 	#import os
 	#print("Installing the reqd libraries...\n")
 	#os.system("pip install tensorflow==2.2.0")
 	#os.system("pip install keras==2.4.3")
 	import tensorflow as tf
-	if tf.__version__ == '2.4.0':
-		pass
-	else:
+	if tf.__version__ != '2.4.0':
 		print("Error! Tensorflow version mismatch...")
